ReinforcementEngine

Struct ReinforcementEngine 

pub struct ReinforcementEngine { /* private fields */ }
Reinforcement feedback engine

Implementations

Source

impl ReinforcementEngine

pub fn with_linucb(alpha: f64, reward_weights: RewardWeights) -> Self

Create a new reinforcement engine with LinUCB

pub fn with_contextual_thompson(reward_weights: RewardWeights) -> Self

Create a new reinforcement engine with Contextual Thompson Sampling

pub fn create_policy( &self, policy_name: impl Into<String>, variants: Vec<(Uuid, ModelConfig)>, ) -> Result<()>

Create a new experiment/policy

pub fn select_variant( &self, policy_name: &str, context: &RequestContext, ) -> Result<(Uuid, ModelConfig)>

Select best variant for given context

pub fn update_from_metrics( &self, policy_name: &str, variant_id: &Uuid, context: &RequestContext, metrics: &ResponseMetrics, ) -> Result<()>

Update with observed reward from metrics only

pub fn update_from_feedback( &self, policy_name: &str, variant_id: &Uuid, context: &RequestContext, metrics: &ResponseMetrics, feedback: &UserFeedback, ) -> Result<()>

Update with observed reward from metrics and user feedback

pub fn get_policy_stats(&self, policy_name: &str) -> Result<Vec<VariantStats>>

Get current performance statistics for all variants in a policy

pub fn algorithm(&self) -> BanditAlgorithm

Get algorithm type

pub fn set_reward_weights(&mut self, weights: RewardWeights)

Update reward calculator weights